# With UsrMove (F-17, RHEL-7 onwards), we want the library installed to %%{_libdir} rather than /%%{_lib}
%global UsrMove %([ 0%{?fedora} -gt 16 -o 0%{?rhel} -gt 6 ] && echo 1 || echo 0)

Summary:	A filesystem driver for WebDAV
Name:		davfs2
Version:	1.6.0
Release:	1.0.cf%{?dist}
License:	GPLv2+
URL:		http://savannah.nongnu.org/projects/davfs2
Source0:	http://savannah.nongnu.org/download/davfs2/davfs2-%{version}.tar.gz
Patch1:		davfs2-1.5.4-cflags.patch
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	fuse
BuildRequires:	gcc
BuildRequires:	gettext
BuildRequires:	make
BuildRequires:	neon-devel >= 0.27
BuildRequires:	sed
BuildRequires:	symlinks
Requires(pre):	glibc-common
Requires(pre):	shadow-utils
Requires:	fuse
%if %{UsrMove}
Conflicts:	filesystem < 3
%endif
Obsoletes:	fuse-davfs2 < %{version}-%{release}
Provides:	fuse-davfs2 = %{version}-%{release}

%description
davfs2 is a FUSE file system driver that allows you to mount a WebDAV server
as a local file system, like a disk drive. This way applications can access
resources on a Web server without knowing anything about HTTP or WebDAV.

davfs2 runs as a daemon in userspace. It uses the kernel file system coda or
fuse. Most probably your Linux kernel includes at least one of these file
systems.

%prep
%setup -n davfs2-%{version} -q

# Drop use of -fstack-protector-strong on old distributions
# where it's not supported
%if 0%{?fedora} < 19 && 0%{?rhel} < 7
%patch1
%endif

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
%if %{UsrMove}
	ssbindir=%{_sbindir} \
%endif
	%{nil}
%if 0%{?fedora} && 0%{?fedora} < 9
# -Werror=format-security nor supported prior to F-9
find . -name Makefile -exec sed -i -e 's/-Werror=format-security//' {} \;
%endif
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} INSTALL="install -p"

# Add symlinks for mount and umount commands in /sbin where mount will expect to find them
%if ! %{UsrMove}
ln -s -f %{buildroot}%{_sbindir}/mount.davfs %{buildroot}/sbin/mount.davfs
ln -s -f %{buildroot}%{_sbindir}/umount.davfs %{buildroot}/sbin/umount.davfs
symlinks -cs %{buildroot}/sbin
%endif

# Create home directory for the davfs2 account
mkdir -p %{buildroot}%{_localstatedir}/cache/davfs2

# Create directory for PID files
mkdir -p %{buildroot}%{_localstatedir}/run/mount.davfs

# We'll package docs ourselves
rm -rf %{buildroot}%{_docdir}

# Remove suid bit, to work around a problem with brp-strip on suid binaries
# (re-added in %%files section)
chmod 0755 %{buildroot}%{_sbindir}/mount.davfs

%find_lang davfs2

%pre
# Create group that normal users must be a member of to use mount.davfs
getent group davfs2 >/dev/null || groupadd -r davfs2

# Create user that mount.davfs will run as when invoked by root
getent passwd davfs2 >/dev/null || \
	useradd -r -s /sbin/nologin -g davfs2 \
		-d %{_localstatedir}/cache/davfs2 \
		-c "WebDAV user id for root" davfs2
exit 0

%files -f davfs2.lang
%if 0%{?_licensedir:1}
%license COPYING
%else
%doc COPYING
%endif
%doc AUTHORS BUGS ChangeLog FAQ NEWS README* THANKS TODO
%doc %{_mandir}/man5/davfs2.conf.5*
%doc %{_mandir}/man8/mount.davfs.8*
%doc %{_mandir}/man8/umount.davfs.8*
%doc %{_mandir}/de/man5/davfs2.conf.5*
%doc %{_mandir}/de/man8/mount.davfs.8*
%doc %{_mandir}/de/man8/umount.davfs.8*
%doc %{_mandir}/es/man5/davfs2.conf.5*
%config(noreplace) %{_sysconfdir}/davfs2/davfs2.conf
%config(noreplace) %{_sysconfdir}/davfs2/secrets
%dir %{_sysconfdir}/davfs2/
%dir %{_sysconfdir}/davfs2/certs/
%dir %{_sysconfdir}/davfs2/certs/private/
%if ! %{UsrMove}
/sbin/mount.davfs
/sbin/umount.davfs
%endif
%attr (4755,root,root) %{_sbindir}/mount.davfs
%{_sbindir}/umount.davfs
%dir %attr(0775,davfs2,davfs2) %{_localstatedir}/cache/davfs2/
%dir %attr(01775,root,davfs2)  %{_localstatedir}/run/mount.davfs/
%{_datadir}/davfs2/

%changelog
* Fri Aug  7 2020 Paul Howarth <paul@city-fan.org> - 1.6.0-1.0.cf
- Update to 1.6.0
  - davfs2 no longer support the use of the Coda kernel file system (it would
    have required some changes); the fuse kernel file system is better suited
    anyway and is part of the official Linux kernel for many years now, so Coda
    is no longer required
  - The Neon library from version 0.31 on has a workaraound for some XML bugs
    of SharePoint concerning file names; option "sharepoint_href_bug 1" will
    activate this workaround
  - Some bug fixes

* Tue Jul 28 2020 Paul Howarth <paul@city-fan.org> - 1.5.6-3.0.cf
- Fix FTBFS with neon 0.31 (https://savannah.nongnu.org/bugs/?58101)

* Thu Jan 23 2020 Paul Howarth <paul@city-fan.org> - 1.5.6-2.0.cf
- Fix FTBFS with GCC 10

* Tue Dec 31 2019 Paul Howarth <paul@city-fan.org> - 1.5.6-1.0.cf
- Update to 1.5.6
  - Various fixes in umount_davfs:
    - Replace GNU extension 'a' with option 'm' in fscanf, fixing crash on
      umount (Bug #56286)
    - Remove calls to setuid and setgid
    - Adjust message
  - Ignore EEXIST when creating DAV_SYS_RUN (Bug #57233)
  - Check for iconv.h and iconv (Bug #56178)

* Fri Jan 25 2019 Paul Howarth <paul@city-fan.org> - 1.5.5-1.0.cf
- Update to 1.5.5
  - Fix cookie parsing error (Debian Bug#834615)
  - Fix infinite loop in cache.c, is_busy (Bug#50083)
  - Ignore option "nofail" (fixes Bug#51521)
  - Add query-string to path on redirect (Bug#54943)
  - Don't remove cache-files because of inconsistent metadata (SR#109587)
  - Add warning in davfs2.conf.5 about intermediary CAs (Bug#54699)
  - Fix some spelling errors
- Drop UTF8 patch, no longer needed

* Mon Mar 19 2018 Paul Howarth <paul@city-fan.org> - 1.5.4-7.0.cf
- Improve readability of scriptlets by getting rid of full command paths
- Avoid file-based dependencies

* Thu Aug 10 2017 Paul Howarth <paul@city-fan.org> - 1.5.4-6.0.cf
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Mon Apr 18 2016 Paul Howarth <paul@city-fan.org> - 1.5.4-1.0.cf
- Update to 1.5.4
  - Remove useless call of is_mounted (SR #109009)
  - For kernel_fs fuse: when getting SIGTERM, unmount while dav_fuse_loop is
    still running
  - Add documentation about required local cache space
  - Use --fstack-protector-strong
- Add patch to drop use of -fstack-protector-strong on old distributions where
  it's not supported
- Update UTF-8 patch

* Wed Apr  6 2016 Paul Howarth <paul@city-fan.org> - 1.5.3-1.0.cf
- Update to 1.5.3
  - Fix stack smashing error (Debian bug #812456)

* Fri Sep 26 2014 Paul Howarth <paul@city-fan.org> - 1.5.2-1.0.cf
- Update to 1.5.2
  - Fixes a problem when unmounting, caused by a backward-incompatible change
    of util-linux
- Update UTF-8 patch

* Fri Aug 22 2014 Paul Howarth <paul@city-fan.org> - 1.5.1-1.0.cf
- Update to 1.5.1
  - Some bug fixes and minor improvements (see ChangeLog for full details)
- Avoid unsupported compiler option -Werror=format-security on Fedoras prior
  to 9
- Use %%license where possible

* Tue Apr 22 2014 Paul Howarth <paul@city-fan.org> - 1.5.0-1.0.cf
- Update to 1.5.0
  - Fixed security risk caused by insecure use of system() (Bug #40034)
  - umount will now properly work with systems where mtab is a symbolic link to
    /proc/mounts; for this, davfs2 uses the new /var/mount/utab file
    (SR #108528)
  - Symbolic links in fstab will no longer break davfs2 (SR #108377)
  - Fixed bugs with setting access bits and evaluating access permissions
    (Bug #33644 and Bug #33644)
  - Support Neon version 0.30 (SR #108392)
  - Improved configuration for certificate validation with new options
    trust_ca_cert and trust_server_cert
  - New option minimize_mem to reduce memory consumption by davfs2 (SR #108158)
  - Allow mount option comment= (Bug #41354)
  - New mount option grpid (SR #108432)
  - Improved cookie support allows for more than one cookie (SR #107907,
    Bug #41438)
  - Honor configure parameter --manfile (SR #108173)
  - Fixed DESTDIR bug (SR #108104)
  - Experimental new features:
    - Support temporary redirects for downloading of files (Bug #35428)
    - Support compression for downloading (Bug #41355); not necessarily
      RFC-compliant, but what is used by browsers
  - Removed features:
    - Support for extended attributes was more then rudimentary and is now
      removed for the sake of performance and clarity
- Bump neon version requirement to 0.27
- Update patches as needed

* Fri Sep 20 2013 Paul Howarth <paul@city-fan.org> - 1.4.7-3.0.cf
- CVE-2013-4362: Fix possibly insecure use of system()

* Fri Sep 13 2013 Paul Howarth <paul@city-fan.org> - 1.4.7-2.0.cf
- Add support for building with neon 0.30
- Don't try to use unsupported configure --disable-static option
- Use -fno-strict-aliasing

* Fri Jul 20 2012 Paul Howarth <paul@city-fan.org> - 1.4.7-1.0.cf
- Update to 1.4.7
  - Search fstab additionally for mount point with trailing slash (Debian
    Bug #580227)
  - Fix various format-string issues
  - Remove check for someone else's home directory (SR #107641)
  - Check return values of system calls
  - Remove fixed length buffer, parse config line in place (Bug #33412)
  - Check for all but temporary errors on USERINFO
  - Fix integer overflow in cache code
  - Fix string comparison in cache code (Bug #33644)
  - Fix client certificate reading issue
  - Translate HTTP 405 into ENOENT (http://savannah.nongnu.org/support/?107869)
  - Quote mpoint in umount_command
  - Get auxiliary groups with getgroups.
- Update UTF-8 patch

* Mon Apr  2 2012 Paul Howarth <paul@city-fan.org> - 1.4.6-3.0.cf
- For F-17/RHEL-7 onwards, install under /usr and conflict with filesystem < 3
  (https://fedoraproject.org/wiki/Features/UsrMove)
- Nobody else likes macros for commands
- Drop %%defattr, redundant since rpm 4.4
- Use a patch rather than scripted iconv to fix manpage encodings
- Maintain timestamps from upstream release where possible

* Tue May  4 2010 Paul Howarth <paul@city-fan.org> - 1.4.6-1.0.cf
- Update to 1.4.6
  - add missing sys/stat.h (bug #28916)
  - fix wrong assignment of password from pam_mount (bug #28706)
- Drop upstreamed davfs2-1.4.5-sys_stat_h.patch
- Tidy up %%description

* Tue Feb 16 2010 Paul Howarth <paul@city-fan.org> - 1.4.5-2.0.cf
- Add davfs2-1.4.5-sys_stat_h.patch to fix building on F-13

* Mon Nov 16 2009 Paul Howarth <paul@city-fan.org> - 1.4.5-1.0.cf
- Update to 1.4.5 (don't prompt about unverified certificates if "askauth 0")

* Mon Oct 19 2009 Paul Howarth <paul@city-fan.org> - 1.4.3-1.0.cf
- Update to 1.4.3
  - support for NTLM authentication (with Neon 0.29 only)
  - change to option askauth behaviour for non-trusted certificates
  - various bugfixes (see ChangeLog)
- Requires: fuse
- Don't use a specific mirror for the source0 URL
- Don't self-obsolete

* Fri Jul 10 2009 Paul Howarth <paul@city-fan.org> - 1.4.1-2.0.cf
- Don't remove %%{_datadir}/davfs2 from package - mount.davfs copies config
  files from there to ~/.davfs2 if there aren't any present already
- Don't ship davfs2.conf and secrets as %%doc (already included in /etc)

* Mon Jun 15 2009 Paul Howarth <paul@city-fan.org> - 1.4.1-1.0.cf
- Update to 1.4.1 (retry uploads on connection failures)
- Include files patch for 1.4.0 now upstream

* Fri May  8 2009 Paul Howarth <paul@city-fan.org> - 1.4.0-1.0.cf
- Update to 1.4.0 (see NEWS for details of signficant config changes)
- Upstream moved to Savannah, fix URLs
- 2-arg open() problem fixed upstream, remove patch
- cache.c needs stdlib.h, apply patch to fix builds on some older platforms
- Add version (>= 0.25) requirement for neon-devel

* Fri Mar 20 2009 Paul Howarth <paul@city-fan.org> - 1.3.3-2.0.cf
- Rename to davfs2 as per the recently-imported version in Fedora
- Provide/Obsolete fuse-davfs2 for upgrade path
- Change group to System Environment/Base
- Include directory %%{_localstatedir}/run/mount.davfs for PID files
- Add symlinks for mount/umount commands in /sbin rather than moving them from
  %%{_sbindir} to /sbin
- Remove %%{_datadir}/davfs2, duplicate of %%{_sysconfdir}/davfs2
- Ensure that %%pre scriptlet always exits successfully
- Add group write permission for directory %%{_localstatedir}/cache/davfs2/
- Don't actually need buildreq fuse-devel, or fuse dependency

* Tue Feb 17 2009 Paul Howarth <paul@city-fan.org> - 1.3.3-1.cf
- Import from RPMforge
- Update to 1.3.3
- Create user and group davfs2 in %%pre
- License is GPL version 2 or later
- Recode German and Spanish manpages as UTF-8
- Add dist tag

* Sat Nov 10 2007 Dag Wieers <dag@wieers.com> - 1.2.2-1 - 5397+/dag
- Updated to release 1.2.2.

* Sat May 12 2007 Dag Wieers <dag@wieers.com> - 1.2.1-1
- Initial package. (using DAR)
